@@ -3,30 +3,53 @@ package Alias::Any;
 use 5.012;
 use warnings;
 
-our $VERSION = '0.000005';
+our $VERSION = '0.000006';
 
-use Keyword::Declare;
+use Keyword::Simple;
+
+# Make 'keyword' and 'unkeyword' no-ops, unless Keyword::Declare is later loaded...
+BEGIN {
+    sub _delete_source { my $ref = shift; $$ref =~ s{ \A .*? [#]END_OF_ALIAS }{}xms; }
+    Keyword::Simple::define(   keyword => \&_delete_source );
+    Keyword::Simple::define( unkeyword => \&_delete_source );
+}
 
 sub import {
-    keyword alias (Variable|VariableDeclaration $variable, '=', Expr $expr) {
-        if ($^V >= 5.022) {
-            qq{use feature 'refaliasing';}
-          . qq{no warnings 'experimental::refaliasing';}
-          . qq{\\$variable = \\$expr}
-        }
-        else {
-            eval { require Data::Alias; 1 }
-                // die "'alias' keyword requires Data::Alias module under Perl $^V\nat "
-                 . join(' line ', (caller 2)[1,2]) . "\n";
-            qq{Data::Alias::alias $variable = $expr}
-        }
+    # Below 5.22, alias keyword just injects Data::Alias...
+    if ($^V <  5.022) {
+        Keyword::Simple::define(
+            alias => sub {
+                my $ref = shift;
+                $$ref = q{use Data::Alias; Data::Alias::alias} . $$ref;
+            }
+        );
     }
+
+    # Above 5.22, alias keyword replaced with built-in syntax...
+    use if $^V >= 5.022, 'Keyword::Declare';
+
+    keyword alias (Variable|VariableDeclaration $variable, '=', Expr $expr) {{{
+        use feature 'refaliasing';
+        no warnings 'experimental::refaliasing';
+        \<{$variable}> = \<{$expr}>
+    }}} #END_OF_ALIAS
 }
 
 sub unimport {
-    unkeyword alias;
+    # Below 5.22, alias keyword is undefined by Keyword::Simple...
+    if ($^V < 5.022) {
+        Keyword::Simple::undefine('alias');
+        if ($Keyword::Simple::VERSION < 0.04) {
+            $^H{'Keyword::Simple/keywords'} =~ s{ alias:(?:\d+|-\d*)}{}g;
+        }
+    }
+
+    # Above 5.22, alias keyword is unkeyworded by Keyword::Declare...
+    use if $^V >= 5.022, 'Keyword::Declare';
+    unkeyword alias; #END_OF_ALIAS
 }
 
+
 1; # Magic true value required at end of module
 __END__
 
@@ -37,7 +60,7 @@ Alias::Any - Create lexical aliases under different versions of Perl
 
 =head1 VERSION
 
-This document describes Alias::Any version 0.000005
+This document describes Alias::Any version 0.000006
 
 
 =head1 SYNOPSIS
@@ -51,6 +74,7 @@ This document describes Alias::Any version 0.000005
 
     alias my %hash_alias = %hash_var;
 
+
     no Alias::Any;
 
     alias my $var = $ref;    # Syntax error
@@ -64,15 +88,14 @@ by which aliases can be defined under different versions of Perl.
 Under Perl 5.12 to 5.18, the module uses the 'alias' function
 from the Data::Alias module to create the requested alias.
 
-But Data::Alias doesn't work under Perl 5.24 or later, so under Perl
-5.22 or later, the module uses the built-in refaliasing mechanism.
-
-(Unfortunately, the module does not work at all under Perl 5.20, because
-of a long-standing problem with compilation of large recursive regexes
-in that release.)
+But previous releases of Data::Alias didn't work under Perl 5.24 or
+later, and from Perl 5.22 there is a more robust built-in aliasing
+mechanism available anyway. So under Perl 5.22 or later, this module
+uses the built-in mechanism in preference to Data::Alias.
 
 This means you can define simple aliases using a consistent syntax,
-without needing to worry which version of Perl your code will run under.
+without needing to worry which version of Perl (or Data::Alias)
+your code will vebe running under.
 
 
 =head1 INTERFACE
@@ -82,20 +105,29 @@ requested alias. The syntax of the keyword is:
 
     alias <new_alias> = <existing_thing>;
 
-The new alias must be a variable (or variable declaration). The
-"existing thing" must either be a variable of the same type as the
-alias (i.e. scalar, array, or hash), or (if the alias is a scalar
-variable) a constant:
+The new alias must be a variable (or a variable declaration). The
+"existing thing" must either be an expression yielding a variable
+of the same type as the alias (i.e. scalar, array, or hash):
+
+    alias $value = $another_value;
+    alias @list  = @another_list;
+    alias @data  = @{ get_data_as_array_ref() };
+
+If the alias is a scalar variable the expression can also be a
+scalar constant:
 
     alias $PI = 3.1415926;
 
-In the latter case, of course, the alias will be a constant too.
+In the latter case, of course, the alias will be immutabe too.
 
-To remove the C<alias> keyword for the rest of the current lexical 
+To remove the C<alias> keyword for the rest of the current lexical
 scope, use:
 
     no Alias::Any;
 
+Note that this only removes the C<alias> keyword; it will have no effect
+on any aliases already defined at that point.
+
 
 =head1 DIAGNOSTICS
 
@@ -106,11 +138,12 @@ scope, use:
 Under Perl 5.12 to 5.18, the module uses Data::Alias to implement
 its magic. You used the module, but it couldn't load Data::Alias.
 
-=item C<< syntax error at t/no_alias.t line 21, near "alias" >>
+=item C<< syntax error at %s, near "alias" >>
 
 You attempted to declare an alias at a point in the code where the
 C<alias> keyword was not installed. Did you forget to put a
 S<C<use Alias::Any;>> earlier in that lexical scope?
+
 Or did you insert a S<C<no Alias::Any;>> somewhere above the alias?
 
 =back
@@ -131,8 +164,8 @@ Alias::Any requires no configuration files or environment variables.
 
 =head1 DEPENDENCIES
 
-Keyword::Declare
-Data::Alias (under Perl 5.18 or earlier)
+Keyword::Declare (under Perl 5.22 or later)
+Data::Alias      (under Perl 5.20 or earlier)
 
 
 =head1 INCOMPATIBILITIES
@@ -142,9 +175,8 @@ None reported.
 
 =head1 BUGS AND LIMITATIONS
 
-The module defines a new C<alias> keyword using the Keyword::Declare
-module, so it only works under Perl 5.12 or later, but not under
-Perl 5.20.
+The module defines a new C<alias> keyword, so it only works under Perl
+5.12 or later.
 
 No bugs have been reported.
 
